Documentation
¶
Index ¶
- func RegisterAppExtended(router *ipc.Router, appName string)
- func RegisterClipboard(router *ipc.Router, policy *security.Policy)
- func RegisterDialog(router *ipc.Router, policy *security.Policy)
- func RegisterFS(router *ipc.Router, policy *security.Policy)
- func RegisterMenu(router *ipc.Router, policy *security.Policy)
- func RegisterNotification(router *ipc.Router, policy *security.Policy)
- func RegisterShell(router *ipc.Router, policy *security.Policy)
- func RegisterSystem(router *ipc.Router, appVersion string, appName string, wv webview.Webview)
- func RegisterTray(router *ipc.Router, policy *security.Policy)
- func RegisterWindow(router *ipc.Router, wv webview.Webview)
- func RegisterWindowExtended(router *ipc.Router, wv webview.Webview)
- func SetupDevTray(evalFunc func(string))
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterAppExtended ¶
RegisterAppExtended registers extended app API handlers. These include badge count, second instance detection, and protocol handling.
func RegisterClipboard ¶
RegisterClipboard registers clipboard API handlers with security checks.
func RegisterDialog ¶
RegisterDialog registers dialog API handlers with security checks.
func RegisterFS ¶
RegisterFS registers file system API handlers with security checks.
func RegisterMenu ¶
RegisterMenu registers application menu API handlers with security checks.
func RegisterNotification ¶
RegisterNotification registers notification API handlers with security checks.
func RegisterShell ¶
RegisterShell registers shell API handlers with security checks.
func RegisterSystem ¶
RegisterSystem registers system info API handlers.
func RegisterTray ¶
RegisterTray registers system tray API handlers with security checks.
func RegisterWindow ¶
RegisterWindow registers window management API handlers.
func RegisterWindowExtended ¶
RegisterWindowExtended registers extended window API handlers. These are window APIs beyond the basic set (setTitle, setSize, etc.) that are registered separately to keep the core window.go minimal.
func SetupDevTray ¶
func SetupDevTray(evalFunc func(string))
Types ¶
This section is empty.