api

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterAppExtended

func RegisterAppExtended(router *ipc.Router, appName string)

RegisterAppExtended registers extended app API handlers. These include badge count, second instance detection, and protocol handling.

func RegisterClipboard

func RegisterClipboard(router *ipc.Router, policy *security.Policy)

RegisterClipboard registers clipboard API handlers with security checks.

func RegisterDialog

func RegisterDialog(router *ipc.Router, policy *security.Policy)

RegisterDialog registers dialog API handlers with security checks.

func RegisterFS

func RegisterFS(router *ipc.Router, policy *security.Policy)

RegisterFS registers file system API handlers with security checks.

func RegisterMenu

func RegisterMenu(router *ipc.Router, policy *security.Policy)

RegisterMenu registers application menu API handlers with security checks.

func RegisterNotification

func RegisterNotification(router *ipc.Router, policy *security.Policy)

RegisterNotification registers notification API handlers with security checks.

func RegisterShell

func RegisterShell(router *ipc.Router, policy *security.Policy)

RegisterShell registers shell API handlers with security checks.

func RegisterSystem

func RegisterSystem(router *ipc.Router, appVersion string, appName string, wv webview.Webview)

RegisterSystem registers system info API handlers.

func RegisterTray

func RegisterTray(router *ipc.Router, policy *security.Policy)

RegisterTray registers system tray API handlers with security checks.

func RegisterWindow

func RegisterWindow(router *ipc.Router, wv webview.Webview)

RegisterWindow registers window management API handlers.

func RegisterWindowExtended

func RegisterWindowExtended(router *ipc.Router, wv webview.Webview)

RegisterWindowExtended registers extended window API handlers. These are window APIs beyond the basic set (setTitle, setSize, etc.) that are registered separately to keep the core window.go minimal.

func SetupDevTray

func SetupDevTray(evalFunc func(string))

Types

This section is empty.

Jump to